package jcg.zheng.demo.scheduler.quartz;

import org.quartz.CronScheduleBuilder;
import org.quartz.Job;
import org.quartz.JobBuilder;
import org.quartz.JobDetail;
import org.quartz.Scheduler;
import org.quartz.SimpleScheduleBuilder;
import org.quartz.Trigger;
import org.quartz.TriggerBuilder;
import org.quartz.impl.StdSchedulerFactory;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class QuartzScheduler {
	static Logger logger = LoggerFactory.getLogger(QuartzScheduler.class);

	private static final String TRIGGER_NAME = "MyTriggerName";
	private static final String JOB_NAME = "someJob";
	private static final String CRON_EXPRESSION_EVERY_SECOND_1 = "1 * * * * ?";

	private Scheduler scheduler;

	public void start() throws Exception {
		logger.info("QuartzScheduler started. ");
		scheduler = new StdSchedulerFactory().getScheduler();
	
		scheduleJob(buildCronSchedulerTrigger("cronGroup"), QuartzJob_HandleException.class, "cronGroup");
		scheduleJob(buildSimpleSchedulerTrigger("simpleGroup"), QuartzJob.class, "simpleGroup");
		scheduler.start();
	}

	private void scheduleJob(Trigger trigger, Class<? extends Job> jobClass, String groupName) throws Exception {
		JobDetail someJobDetail = JobBuilder.newJob(jobClass).withIdentity(JOB_NAME, groupName).build();
		scheduler.scheduleJob(someJobDetail, trigger);
	}

	private Trigger buildCronSchedulerTrigger(String groupName) {
		return TriggerBuilder
				.newTrigger().withIdentity(TRIGGER_NAME, groupName).withSchedule(CronScheduleBuilder
						.cronSchedule(CRON_EXPRESSION_EVERY_SECOND_1).withMisfireHandlingInstructionDoNothing())
				.build();
	}

	private Trigger buildSimpleSchedulerTrigger(String groupName) {
		return TriggerBuilder
				.newTrigger().withIdentity(TRIGGER_NAME, groupName).withSchedule(SimpleScheduleBuilder.simpleSchedule()
						.withRepeatCount(30).withIntervalInMinutes(1).withMisfireHandlingInstructionIgnoreMisfires())
				.build();
	}
}
